#[repr(u8)]pub enum Frr {
RESTART = 0,
FREE_RUN = 1,
}Variants
RESTART = 0
Restart mode. After a compare event, the counter resets to 0x0000_0000 and resumes counting.
FREE_RUN = 1
Free-Run mode. After a compare event, the counter continues counting until 0xFFFF_FFFF and then rolls over to 0.
Implementations