#[repr(u8)]pub enum Om3 {
DISABLED = 0,
TOGGLE = 1,
CLEAR = 2,
SET = 3,
PULSE = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
}Variants
DISABLED = 0
Output disabled. No response on pin.
TOGGLE = 1
Toggle output pin
CLEAR = 2
Clear output pin
SET = 3
Set output pin
PULSE = 4
Generate a low pulse that is one input clock cycle wide on the output pin. When OMn is first programmed as 1xx, the output pin is set to one immediately on the next input clock (if it was not one already). “Input clock” here refers to the clock selected by the CLKSRC field of this register.
_RESERVED_5 = 5
_RESERVED_6 = 6
_RESERVED_7 = 7
Implementations